@@ -2,8 +2,8 @@
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * License as published by the Free Software Foundation version 2.1
+ * of the License.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,11 +16,13 @@
  */
 
 #include "hime.h"
+
 #include "hime-im-client.h"
 
-void send_hime_message(Display *dpy, char *s)
-{
-  HIME_client_handle *handle = hime_im_client_open(dpy);
-  hime_im_client_message(handle, s);
-  hime_im_client_close(handle);
+void send_hime_message (Display *display, const char *message) {
+    if (display) {
+        HIME_client_handle *handle = hime_im_client_open (display);
+        hime_im_client_send_message (handle, message);
+        hime_im_client_close (handle);
+    }
 }
