@@ -2,8 +2,8 @@
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * License as published by the Free Software Foundation version 2.1
+ * of the License.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,27 +16,27 @@
  */
 
 #include "hime.h"
+
 #include "pho.h"
 
-static int shiftb[]={9,7,3,0};
+static int shiftb[] = {9, 7, 3, 0};
 
-int lookup(u_char *s)
-{
-  int i;
-  char tt[CH_SZ+1], *pp;
+int lookup (u_char *s) {
+    int i;
+    char tt[CH_SZ + 1], *pp;
 
-  if (*s < 128)
-    return *s-'0';
+    if (*s < 128)
+        return *s - '0';
 
-  bchcpy(tt, s);
-  tt[PHO_CHAR_LEN]=0;
+    bchcpy (tt, s);
+    tt[PHO_CHAR_LEN] = 0;
 
-  for(i=0;i<3;i++)
-    if ((pp=strstr(pho_chars[i],tt)))
-      break;
+    for (i = 0; i < 3; i++)
+        if ((pp = strstr (pho_chars[i], tt)))
+            break;
 
-  if (i==3)
-    return 0;
+    if (i == 3)
+        return 0;
 
-  return (((pp-pho_chars[i])/3) << shiftb[i]);
+    return (((pp - pho_chars[i]) / 3) << shiftb[i]);
 }
